PyXMake Developer Guide: PyXMake.VTL.archive Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions | Variables
PyXMake.VTL.archive Namespace Reference

## Functions
| main (BuildID, source=__pyx_src_path, output=os.getcwd(), exclude=[".git", ".svn", "__pycache__"], **kwargs)

## Variables
| parser = argparse.ArgumentParser(description='CLI wrapper options for archive generator.')
| type
| str
| nargs
| help
| default
| _ = sys.argv[1]
| args
| project = args.name[0] ;
| source = args.source[0] ;
| output
| excludes
| exclude

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Compile a stand-alone application using PyInstaller
    Created on 02.05.2020

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake

    @change:
          - Requires PyCODAC in PYTHONPATH.

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.VTL.archive.main | ( |  | BuildID,
|  |  | source = __pyx_src_path,
|  |  | output = os.getcwd(),
|  |  | exclude = [".git", ".svn", "__pycache__"],
|  | ** | kwargs )

    Main function to execute the script.

Definition at line 39 of file archive.py.

## Variable Documentation

## ◆ _

PyXMake.VTL.archive._ = sys.argv[1]
| protected

Definition at line 69 of file archive.py.

## ◆ args

PyXMake.VTL.archive.args

Definition at line 70 of file archive.py.

## ◆ default

PyXMake.VTL.archive.default

Definition at line 65 of file archive.py.

## ◆ exclude

PyXMake.VTL.archive.exclude

Definition at line 86 of file archive.py.

## ◆ excludes

PyXMake.VTL.archive.excludes

Definition at line 79 of file archive.py.

## ◆ help

PyXMake.VTL.archive.help

Definition at line 62 of file archive.py.

## ◆ nargs

PyXMake.VTL.archive.nargs

Definition at line 62 of file archive.py.

## ◆ output

PyXMake.VTL.archive.output

Definition at line 76 of file archive.py.

## ◆ parser

PyXMake.VTL.archive.parser = argparse.ArgumentParser(description='CLI wrapper options for archive generator.')

Definition at line 61 of file archive.py.

## ◆ project

PyXMake.VTL.archive.project = args.name[0] ;

Definition at line 72 of file archive.py.

## ◆ source

PyXMake.VTL.archive.source = args.source[0] ;

Definition at line 74 of file archive.py.

## ◆ str

PyXMake.VTL.archive.str

Definition at line 62 of file archive.py.

## ◆ type

PyXMake.VTL.archive.type

Definition at line 62 of file archive.py.